==> estateplat-common-1.2.1-20170622.071222-42-sources.jar: cn/gtmap/estateplat/model/exchange/share/GxJyQlr.java <==
package cn.gtmap.estateplat.model.exchange.share;

import javax.persistence.Table;
import java.io.Serializable;

/**
 * @author <a href="mailto:shenjian@gtmap.cn">jane</a>
 * @version 1.0, 2016/4/12
 * @description 共享交易审批权利人
 */
@Table(name = "GX_JY_QLR")
public class GxJyQlr implements Serializable {
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @description 业务号
     */
    private String ywh;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @description 权利人名称
     */
    private String qlrmc;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @description 证件种类
     */
    private String zjzl;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @description 证件号
     */
    private String zjh;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @description 发证机关
     */
    private String fzjg;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @description 所属行业
     */
    private String sshy;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @description 国家
     */
    private String gj;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @description 户籍所在省市
     */
    private String hjszss;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @description 性别
     */
    private String xb;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @description 电话
     */
    private String dh;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @description 地址
     */
    private String dz;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @description 邮编
     */
    private String yb;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @description 工作单位
     */
    private String gzdw;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @description 电子邮件
     */
    private String dzyj;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @description 权利人类别
     */
    private String qlrlb;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @description 备注
     */
    private String bz;

    public String getYwh() {
        return ywh;
    }

    public void setYwh(String ywh) {
        this.ywh = ywh;
    }

    public String getQlrmc() {
        return qlrmc;
    }

    public void setQlrmc(String qlrmc) {
        this.qlrmc = qlrmc;
    }

    public String getZjzl() {
        return zjzl;
    }

    public void setZjzl(String zjzl) {
        this.zjzl = zjzl;
    }

    public String getZjh() {
        return zjh;
    }

    public void setZjh(String zjh) {
        this.zjh = zjh;
    }

    public String getFzjg() {
        return fzjg;
    }

    public void setFzjg(String fzjg) {
        this.fzjg = fzjg;
    }

    public String getSshy() {
        return sshy;
    }

    public void setSshy(String sshy) {
        this.sshy = sshy;
    }

    public String getGj() {
        return gj;
    }

    public void setGj(String gj) {
        this.gj = gj;
    }

    public String getHjszss() {
        return hjszss;
    }

    public void setHjszss(String hjszss) {
        this.hjszss = hjszss;
    }

    public String getXb() {
        return xb;
    }

    public void setXb(String xb) {
        this.xb = xb;
    }

    public String getDh() {
        return dh;
    }

    public void setDh(String dh) {
        this.dh = dh;
    }

    public String getDz() {
        return dz;
    }

    public void setDz(String dz) {
        this.dz = dz;
    }

    public String getYb() {
        return yb;
    }

    public void setYb(String yb) {
        this.yb = yb;
    }

    public String getGzdw() {
        return gzdw;
    }

    public void setGzdw(String gzdw) {
        this.gzdw = gzdw;
    }

    public String getDzyj() {
        return dzyj;
    }

    public void setDzyj(String dzyj) {
        this.dzyj = dzyj;
    }

    public String getQlrlb() {
        return qlrlb;
    }

    public void setQlrlb(String qlrlb) {
        this.qlrlb = qlrlb;
    }

    public String getBz() {
        return bz;
    }

    public void setBz(String bz) {
        this.bz = bz;
    }
}

==> estateplat-common-1.2.4-20191127.062549-186-sources.jar: cn/gtmap/estateplat/model/exchange/share/GxJyQlr.java <==
package cn.gtmap.estateplat.model.exchange.share;

import javax.persistence.Table;
import java.io.Serializable;

/**
 * @author <a href="mailto:shenjian@gtmap.cn">jane</a>
 * @version 1.0, 2016/4/12
 * @description 共享交易审批权利人
 */
@Table(name = "GX_JY_QLR")
public class GxJyQlr implements Serializable {
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @description 业务号
     */
    private String ywh;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @description 权利人名称
     */
    private String qlrmc;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @description 证件种类
     */
    private String zjzl;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @description 证件号
     */
    private String zjh;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @description 发证机关
     */
    private String fzjg;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @description 所属行业
     */
    private String sshy;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @description 国家
     */
    private String gj;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @description 户籍所在省市
     */
    private String hjszss;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @description 性别
     */
    private String xb;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @description 电话
     */
    private String dh;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @description 地址
     */
    private String dz;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @description 邮编
     */
    private String yb;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @description 工作单位
     */
    private String gzdw;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @description 电子邮件
     */
    private String dzyj;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @description 权利人类别
     */
    private String qlrlb;
    /**
     * @author <a href="mailto:liujie@gtmap.cn">liujie</a>
     * @description 顺序号
     */
    private int sxh;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @description 备注
     */
    private String bz;

    public String getYwh() {
        return ywh;
    }

    public void setYwh(String ywh) {
        this.ywh = ywh;
    }

    public String getQlrmc() {
        return qlrmc;
    }

    public void setQlrmc(String qlrmc) {
        this.qlrmc = qlrmc;
    }

    public String getZjzl() {
        return zjzl;
    }

    public void setZjzl(String zjzl) {
        this.zjzl = zjzl;
    }

    public String getZjh() {
        return zjh;
    }

    public void setZjh(String zjh) {
        this.zjh = zjh;
    }

    public String getFzjg() {
        return fzjg;
    }

    public void setFzjg(String fzjg) {
        this.fzjg = fzjg;
    }

    public String getSshy() {
        return sshy;
    }

    public void setSshy(String sshy) {
        this.sshy = sshy;
    }

    public String getGj() {
        return gj;
    }

    public void setGj(String gj) {
        this.gj = gj;
    }

    public String getHjszss() {
        return hjszss;
    }

    public void setHjszss(String hjszss) {
        this.hjszss = hjszss;
    }

    public String getXb() {
        return xb;
    }

    public void setXb(String xb) {
        this.xb = xb;
    }

    public String getDh() {
        return dh;
    }

    public void setDh(String dh) {
        this.dh = dh;
    }

    public String getDz() {
        return dz;
    }

    public void setDz(String dz) {
        this.dz = dz;
    }

    public String getYb() {
        return yb;
    }

    public void setYb(String yb) {
        this.yb = yb;
    }

    public String getGzdw() {
        return gzdw;
    }

    public void setGzdw(String gzdw) {
        this.gzdw = gzdw;
    }

    public String getDzyj() {
        return dzyj;
    }

    public void setDzyj(String dzyj) {
        this.dzyj = dzyj;
    }

    public String getQlrlb() {
        return qlrlb;
    }

    public void setQlrlb(String qlrlb) {
        this.qlrlb = qlrlb;
    }

    public int getSxh() {
        return sxh;
    }

    public void setSxh(int sxh) {
        this.sxh = sxh;
    }

    public String getBz() {
        return bz;
    }

    public void setBz(String bz) {
        this.bz = bz;
    }
}
